#
# spec file for package python-semver
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-semver
Version:        2.10.0
Release:        bp153.1.17
Summary:        Python helper for Semantic Versioning
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/python-semver/python-semver
Source:         https://files.pythonhosted.org/packages/source/s/semver/semver-%{version}.tar.gz
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
# See https://github.com/k-bx/python-semver/issues/67 for why conflicts is needed
Conflicts:      python-node-semver
BuildArch:      noarch
%python_subpackages

%description
A Python module for semantic versioning. Simplifies comparing versions.
See also http://semver.org/

%prep
%setup -q -n semver-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pysemver

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative pysemver

%postun
%python_uninstall_alternative pysemver

%files %{python_files}
%doc README.rst
%{python_sitelib}/semver*
%pycache_only %{python_sitelib}/__pycache__/semver*
%python_alternative %{_bindir}/pysemver

%changelog
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sat May  9 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * updated url
  * moved download url back to pypi (issue with tests not included seems resolved)
- update to version 2.10.0:
  * Features
    + :pr:`138`: Added __getitem__ magic method to semver.VersionInfo
    class. Allows to access a version like version[1].
    + :pr:`235`: Improved documentation and shift focus on
    semver.VersionInfo instead of advertising the old and deprecated
    module-level functions.
  * Bug Fixes
    + :gh:`224` (:pr:`226`): In setup.py, replaced in class clean,
    super(CleanCommand, self).run() with CleanCommand.run(self)
    + :gh:`244` (:pr:`245`): Allow comparison with VersionInfo,
    tuple/list, dict, and string.
  * Additions
    + :pr:`228`: Added better doctest integration
  * Removals
    + :gh:`225` (:pr:`229`): Output a DeprecationWarning for the
    following functions:
  - semver.parse
  - semver.parse_version_info
  - semver.format_version
  - semver.bump_{major,minor,patch,prerelease,build}
  - semver.finalize_version
  - semver.replace
  - semver.VersionInfo._asdict (use the new, public available function semver.VersionInfo.to_dict())
  - semver.VersionInfo._astuple (use the new, public available function semver.VersionInfo.to_tuple())
    These deprecated functions will be removed in semver 3.
* Tue Feb 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.9.1:
  - Features:
  - :gh:`177` (:pr:`178`): Fixed repository and CI links (moved https://github.com/k-bx/python-semver/ repository to https://github.com/python-semver/python-semver/)
  - :pr:`179`: Added note about moving this project to the new python-semver organization on GitHub
  - :gh:`187` (:pr:`188`): Added logo for python-semver organization and documentation
  - :gh:`191` (:pr:`194`): Created manpage for pysemver
  - :gh:`196` (:pr:`197`): Added distribution specific installation instructions
  - :gh:`201` (:pr:`202`): Reformatted source code with black
  - :gh:`208` (:pr:`209`): Introduce new function :func:`semver.VersionInfo.isvalid`
    and extend :command:`pysemver` with :command:`check` subcommand
  - :gh:`210` (:pr:`215`): Document how to deal with invalid versions
  - :pr:`212`: Improve docstrings according to PEP257
  - Bug Fixes:
  - :gh:`192` (:pr:`193`): Fixed "pysemver" and "pysemver bump" when called without arguments
* Tue Nov 26 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.9.0:
  - Version 2.9.0 (WIP):
  - Features:
  - :gh:`59` (:pr:`164`): Implemented a command line interface
  - :gh:`85` (:pr:`147`, :pr:`154`): Improved contribution section
  - :gh:`104` (:pr:`125`): Added iterator to :func:`semver.VersionInfo`
  - :gh:`112`, :gh:`113`: Added Python 3.7 support
  - :pr:`120`: Improved test_immutable function with properties
  - :pr:`125`: Created :file:`setup.cfg` for pytest and tox
  - :gh:`126` (:pr:`127`): Added target for documentation in :file:`tox.ini`
  - :gh:`142` (:pr:`143`): Improved usage section
  - :gh:`144` (:pr:`156`): Added :func:`semver.replace` and :func:`semver.VersionInfo.replace`
    functions
  - :gh:`145` (:pr:`146`): Added posargs in :file:`tox.ini`
  - :pr:`157`: Introduce :file:`conftest.py` to improve doctests
  - :pr:`165`: Improved code coverage
  - :pr:`166`: Reworked :file:`.gitignore` file
  - :gh:`167` (:pr:`168`): Introduced global constant :data:`SEMVER_SPEC_VERSION`
  - Bug Fixes:
  - :gh:`102`: Fixed comparison between VersionInfo and tuple
  - :gh:`103`: Disallow comparison between VersionInfo and string (and int)
  - :gh:`121` (:pr:`122`): Use python3 instead of python3.4 in :file:`tox.ini`
  - :pr:`123`: Improved :func:`__repr__` and derive class name from :func:`type`
  - :gh:`128` (:pr:`129`): Fixed wrong datatypes in docstring for :func:`semver.format_version`
  - :gh:`135` (:pr:`140`): Converted prerelease and build to string
  - :gh:`136` (:pr:`151`): Added testsuite to tarball
  - :gh:`154` (:pr:`155`): Improved README description
  - Removals:
  - :gh:`111` (:pr:`110`): Droped Python 3.3
  - :gh:`148` (:pr:`149`): Removed and replaced ``python setup.py test``
- update to version 2.8.2:
  - Skipped, not released.
* Thu Oct  3 2019 John Vandenberg <jayvdb@gmail.com>
- Add Conflicts: python-node-semver
- Add fdupes
* Thu Jun  6 2019 pgajdos@suse.com
- run the testsuite
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jul 12 2018 arun@gmx.de
- specfile:
  * be more specific for python_sitelib in %%files section
- update to version 2.8.1:
  * Issue #77 (PR #47). Convert multiple tests into
    pytest.mark.parametrize
  * Issue #89 (PR #90). Add doctests.
  * Issue #40 (PR #88). Add a static parse method to VersionInfo
  * Issue #87 #94 (PR #93). Remove named tuple inheritance. Fix bad
    rendering in Pandas DataFrame
  * Issue #96 (PR #97). Make VersionInfo immutable
  * Issue #98 (PR #99). prerelease and build set to None by default
* Mon May 21 2018 sebix+novell.com@sebix.at
- update to version 2.8.0 (excerpt):
  * Issue #79 (PR #81 #84). Define and improve a release procedure file
  * Issue #72 #73 (PR #75). Implements __str__ and __hash__
* Tue Nov 14 2017 arun@gmx.de
- update to version 2.7.9:
  * Issue #65 (PR #66). Add finalize_version function
* Fri Aug 25 2017 sebix+novell.com@sebix.at
- update to 2.7.8
  * PR #62. Support custom default names for pre and build
* Fri Jun  2 2017 sebix+novell.com@sebix.at
- initial package
